@@ -1,28 +1,25 @@
-/* 
-** DAV directory chache
- */
+/*  cache.h: directory and file cache.
+    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
 
-/*
- *  This file is part of davfs2.
- *
- *  davfs2 is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  davfs2 is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with davfs2; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+    This file is part of davfs2.
+
+    davfs2 is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    davfs2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with davfs2; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 
-#ifndef __DAV_CACHE_H__
-#define __DAV_CACHE_H__
+#ifndef DAV_CACHE_H
+#define DAV_CACHE_H
 
 
 /* Constants */
@@ -143,6 +140,7 @@ typedef struct dav_node_item dav_node_list_item;
 struct dav_node_item {
     dav_node_list_item *next;
     dav_node *node;
+    int attempts;
     time_t save_at;
 };
 
@@ -150,13 +148,17 @@ struct dav_node_item {
 /* Returned by dav_statfs(). */
 typedef struct dav_stat dav_stat;
 struct dav_stat {
-    off_t blocks;
-    off_t bfree;
-    off_t bavail;
-    off_t files;
-    off_t ffree;
-    off_t bsize;
-    off_t namelen;
+    off64_t     blocks;
+    off64_t     bfree;
+    off64_t     bavail;
+    off64_t     files;
+    off64_t     ffree;
+    off_t       bsize;
+    off_t       namelen;
+    time_t      utime;      /* Time when last updated with data from the server.
+                               must When 0 this structure contains fake data,
+                               that not be changed when a file is changed or
+                               deleted. */
 };
 
 
@@ -188,13 +190,8 @@ typedef off_t (*dav_write_dir_entry_fn)(int fd, off_t off, const dav_node *node,
    filesystem can be mounted, but will only get useable when the connection
    comes up.
    paramters: if not self explaining, please see mount_davfs.c, struct args. */
-void dav_init_cache(uid_t uid, gid_t gid, mode_t file_mode, mode_t dir_mode,
-                    mode_t f_umask, mode_t d_umask, size_t hash_table_sz,
-                    time_t dir_rf, time_t file_rf, int delay_upl, int gui_opt,
-                    time_t dir_rt, time_t dir_max_rt, time_t lock_rf,
-                    size_t cache_sz, const char *tl_cache_dir,
-                    const char *backup_dir, const char *host, const char *path,
-                    const char *mpoint, int dbg);
+void
+dav_init_cache(const dav_args *args, const char *mpoint);
 
 
 /* Tries to write back to the server all open files that have been changed or
@@ -204,15 +201,17 @@ void dav_init_cache(uid_t uid, gid_t gid, mode_t file_mode, mode_t dir_mode,
    permanent cache is created.
    If got_sigterm is 1, dirty files will not be stored back to the server.
    Finally it frees all nodes. */
-void dav_close_cache(int got_sigterm);
+void
+dav_close_cache(int got_sigterm);
 
 
 /* Registers the kernel_interface.
    Sets pointers to the write_dir_entry_fn flush_flag.
    If blksize is not NULL, the preferred bloksize for IO is asigned.
    It returns the value of alignment. */
-size_t dav_register_kernel_interface(dav_write_dir_entry_fn write_fn,
-                                     int *flush_flag, unsigned int *blksize);
+size_t
+dav_register_kernel_interface(dav_write_dir_entry_fn write_fn, int *flush_flag,
+                              unsigned int *blksize);
 
 
 /* Scans the hash table for file nodes to be saved them back on the server,
@@ -223,7 +222,8 @@ size_t dav_register_kernel_interface(dav_write_dir_entry_fn write_fn,
    The return value indicates whether another run would be useful.
    return value: 0 there is nothing left to do.
                  1 another call of dav_tidy_cache would be useful. */
-int dav_tidy_cache(void);
+int
+dav_tidy_cache(void);
 
 
 /* Upcalls from the kernel, via the interface module. */
@@ -259,7 +259,8 @@ int dav_tidy_cache(void);
 /* Tests whether user uid has access described by how to node.
    int how : A bit mask describing the kind of acces. It may be any combination
              of R_OK, W_OK, X_OK and F_OK. */
-int dav_access(dav_node *node, uid_t uid, int how);
+int
+dav_access(dav_node *node, uid_t uid, int how);
 
 
 /* Closed file descriptor fd of node.
@@ -267,7 +268,8 @@ int dav_access(dav_node *node, uid_t uid, int how);
    opening. If fd is 0 (coda), flags, pid and pgid are used to find the best
    matching file descriptor.
    Only access mode bits must be set in flags.*/
-int dav_close(dav_node *node, int fd, int flags, pid_t pid, pid_t pgid);
+int
+dav_close(dav_node *node, int fd, int flags, pid_t pid, pid_t pgid);
 
 
 /* Creates a new file node with name name in directory parent. The file is
@@ -278,8 +280,9 @@ int dav_close(dav_node *node, int fd, int flags, pid_t pid, pid_t pgid);
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    well as write permission for parent. */
-int dav_create(dav_node **nodep, dav_node *parent, const char *name,
-               uid_t uid, mode_t mode);
+int
+dav_create(dav_node **nodep, dav_node *parent, const char *name, uid_t uid,
+           mode_t mode);
 
 
 /* Checks whether node exists and uid has permissions. The kernel interface
@@ -287,7 +290,8 @@ int dav_create(dav_node **nodep, dav_node *parent, const char *name,
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    well as read permission for parent. */
-int dav_getattr(dav_node *node, uid_t uid);
+int
+dav_getattr(dav_node *node, uid_t uid);
 
 
 /* Checks whether node exists and uid has permissions. The value of
@@ -296,8 +300,15 @@ int dav_getattr(dav_node *node, uid_t uid);
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    well as read permission for parent. */
-int dav_getxattr(dav_node *node, const char *name, char *buf, size_t *size,
-                uid_t uid);
+int
+dav_getxattr(dav_node *node, const char *name, char *buf, size_t *size,
+             uid_t uid);
+
+
+/* Returns the list of supported extended attributes. This is just
+   user.mime_type. */
+int
+dav_listxattr(dav_node *node, char *buf, size_t *size, uid_t uid);
 
 
 /* Searches for a node with name name in the directory parent and returns the
@@ -305,7 +316,8 @@ int dav_getxattr(dav_node *node, const char *name, char *buf, size_t *size,
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    well as read permission for parent. */
-int dav_lookup(dav_node **nodep, dav_node *parent, const char *name, uid_t uid);
+int
+dav_lookup(dav_node **nodep, dav_node *parent, const char *name, uid_t uid);
 
 
 /* Creates a new directory named name in direcotry parent. The directory must
@@ -315,8 +327,9 @@ int dav_lookup(dav_node **nodep, dav_node *parent, const char *name, uid_t uid);
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    well as write permission for parent. */
-int dav_mkdir(dav_node **nodep, dav_node *parent, const char *name, uid_t uid,
-              mode_t mode);
+int
+dav_mkdir(dav_node **nodep, dav_node *parent, const char *name, uid_t uid,
+          mode_t mode);
 
 
 /* Opens file or directory node according to flags and returns file descriptor
@@ -327,16 +340,22 @@ int dav_mkdir(dav_node **nodep, dav_node *parent, const char *name, uid_t uid,
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    as well as read and/or write permission for node, according to the
-   accessmode. */
-int dav_open(int *fd, dav_node *node, int flags, pid_t pid, pid_t pgid,
-             uid_t uid);
+   accessmode.
+   If open_create is set to 1, permissions will not be checked. This flag must
+   only be set when the call to dav_open is part of an open-call with flag
+   O_CREATE. It allows dav_open to succeed if when the file mode would not
+   allow this.  */
+int
+dav_open(int *fd, dav_node *node, int flags, pid_t pid, pid_t pgid, uid_t uid,
+         int open_create);
 
 /* Reads size bytes from file descriptor fd, starting at position offset
    and copies them into buf.
    The number of bytes read is returned in len.
    The file must be opened readonly or readwrite. */
-int dav_read(ssize_t *len, dav_node * node, int fd, char *buf, size_t size,
-             off_t offset);
+int
+dav_read(ssize_t *len, dav_node * node, int fd, char *buf, size_t size,
+         off_t offset);
 
 
 /* Removes file node name in directory parent from the cache and on the server.
@@ -344,7 +363,8 @@ int dav_read(ssize_t *len, dav_node * node, int fd, char *buf, size_t size,
    Permissions:
    uid must have execute permission for parent and all of its ancestors, as
    well as write permission for parent. */
-int dav_remove(dav_node *parent, const char *name, uid_t uid);
+int
+dav_remove(dav_node *parent, const char *name, uid_t uid);
 
 
 /* Moves file or directory src_name from directory src_parent to directory
@@ -356,22 +376,25 @@ int dav_remove(dav_node *parent, const char *name, uid_t uid);
    uid must have execute permission for src_parent and dst_parent and all of
    their ancestors, as well as write permission for src_parent and
    dst_parent. */
-int dav_rename(dav_node *src_parent, const char *src_name,
-               dav_node *dst_parent, const char *dst_name, uid_t uid);
+int
+dav_rename(dav_node *src_parent, const char *src_name, dav_node *dst_parent,
+           const char *dst_name, uid_t uid);
 
 
 /* Removes direcotry name in directory parent.
    The directory must be empty and not the local backup directory.
    uid must have execute permission for parent and all of its ancestors, as
    well as write permission for parent. */
-int dav_rmdir(dav_node *parent, const char *name, uid_t uid);
+int
+dav_rmdir(dav_node *parent, const char *name, uid_t uid);
 
 
 /* Returns a pointer to the root node in nodep.
    Permissions:
    uid must be root, as this function is only called when the file system is
    mounted. */
-int dav_root(dav_node **nodep, uid_t uid);
+int
+dav_root(dav_node **nodep, uid_t uid);
 
 
 /* Changes attributes of the node.
@@ -386,27 +409,32 @@ int dav_root(dav_node **nodep, uid_t uid);
    To change gid, uid must be member of the new group or root.
    Note: This attributes, except size and the execute bit of mode, are only
          changed locally and not on the server. */
-int dav_setattr(dav_node *node, uid_t uid, int sm, mode_t mode,
-                int so, uid_t owner, int sg, gid_t gid, int sat, time_t atime,
-                int smt, time_t mtime, int ssz, off_t size);
+int
+dav_setattr(dav_node *node, uid_t uid, int sm, mode_t mode, int so,
+            uid_t owner, int sg, gid_t gid, int sat, time_t atime, int smt,
+            time_t mtime, int ssz, off_t size);
 
-/* Returns struct dav_stat which currently is mainly fake.
+
+/* Returns struct dav_stat. If the server does not provide theinformation
+   it will contain fake data.
    No permissions necessary. */
-dav_stat dav_statfs(void);
+dav_stat *
+dav_statfs(void);
 
 
 /* Calls fsync() for all filedescriptors of node, that are not read only.
    No permissions are checked. */
-int dav_sync(dav_node *node);
+int
+dav_sync(dav_node *node);
 
 
 /* Writes size bytes from buf to file descriptor fd, starting at position
    offset.
    The number of bytes written is returned in len.
    The file must be opened writeonly or readwrite. */
-/* TODO: Remove pid; check flags. */
-int dav_write(size_t *written, dav_node * node, int fd, char *buf, size_t size,
-              off_t offset);
+int
+dav_write(size_t *written, dav_node * node, int fd, char *buf, size_t size,
+          off_t offset);
 
 
-#endif
+#endif /* DAV_CACHE_H */
