@@ -33,6 +33,8 @@
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
+#include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #ifdef HAVE_SYSLOG_H
 #include <syslog.h>
