@@ -1,35 +1,30 @@
-/* 
-** Default values for constants.
- */
+/*  defauls.h: default values of configuration options and constants.
+    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
 
-/*
- *  This file is part of davfs2.
- *
- *  davfs2 is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  davfs2 is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with davfs2; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+    This file is part of davfs2.
+
+    davfs2 is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    davfs2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with davfs2; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 
-#ifndef __DEFAULTS_H__
-#define __DEFAULTS_H__
+#ifndef DAV_DEFAULTS_H
+#define DAV_DEFAULTS_H
 
 
 /* Misc. */
 /*=======*/
 
-#define DAV_HOME "http://dav.sourceforge.net"
-
 /* File system type to be used with 'mount -t' and fstab. */
 #define DAV_FS_TYPE "davfs"
 
@@ -123,22 +118,18 @@
    May be overridden by command line, fstab or system config file. */
 #define DAV_ASKAUTH 1
 
-/* Use the value of property displayname, if present.
-   May be overridden by system config file and user config file. */
-#define DAV_DISPLAYNAME 0
-
 /* Whether to use locks.
    May be overridden by command line or fstab. */
 #define DAV_LOCKS 1
 
 /* Send expect 100-continue header in PUT requests.
    May be overridden by system config file and user config file. */
-#define DAV_EXPECT100 1
+#define DAV_EXPECT100 0
 
 /* If If-Match and If-None-Match does not work on the server, set to 1.
    Default is 1, as Apache has this bug.
    May be overridden by system config file and user config file. */
-#define DAV_IF_MATCH_BUG 1
+#define DAV_IF_MATCH_BUG 0
 
 /* Some servers sends a weak invalid etag that turns into a valid strong etag
    after one second. With this flag set, the etag will not be used,
@@ -170,15 +161,20 @@
    May be overridden by system config file and user config file. */
 #define DAV_READ_TIMEOUT 30
 
-/* Default retry time after a PROPFIND request failed. When the request fails
+/* Default retry time after a HTTP request failed. When the request fails
    again, the retry time will subsequently be increased up to DAV_MAX_RETRY.
    May be overridden by system config file and user config file. */
 #define DAV_RETRY 30
 
-/* Maximum retry time after a PROPFIND request failed.
+/* Maximum retry time after a HTTP request failed.
    May be overridden by system config file and user config file. */
 #define DAV_MAX_RETRY 300
 
+/* Maximum Number of attempts made to upoad a changed file before it is
+   moved into the lost+found directory.
+   May be overridden by system config file and user config file. */
+#define DAV_MAX_UPLOAD_ATTEMPTS 15
+
 /* Preferred live time of locks in seconds, before they have to be refreshed.
    May be overridden by system config file and user config file. */
 #define DAV_LOCK_TIMEOUT 1800
@@ -197,4 +193,4 @@
 #define DAV_DBG_SECRETS 0x8
 
 
-#endif
+#endif /* DAV_DEFAULTS_H */
