@@ -167,8 +167,7 @@ init_coda(int *dev, dav_run_msgloop_fn *msg_loop, void **mdata)
         ++minor;
     }
 
-    if (*dev <= 0) {
-        system("/sbin/modprobe coda &>/dev/null");
+    if (*dev <= 0 && system("/sbin/modprobe coda &>/dev/null") == 0) {
         minor = 0;
         while (*dev <= 0 && minor < MAX_CODADEVS) {
             char *path;
@@ -178,9 +177,12 @@ init_coda(int *dev, dav_run_msgloop_fn *msg_loop, void **mdata)
             *dev = open(path, O_RDWR | O_NONBLOCK);
             if (*dev <= 0) {
                 if (mknod(path, S_IFCHR, makedev(CODA_MAJOR, minor)) == 0) {
-                    chown(path, 0, 0);
-                    chmod(path, S_IRUSR | S_IWUSR);
-                    *dev = open(path, O_RDWR | O_NONBLOCK);
+                    if (chown(path, 0, 0) == 0
+                            && chmod(path, S_IRUSR | S_IWUSR) == 0) {
+                        *dev = open(path, O_RDWR | O_NONBLOCK);
+                    } else {
+                        remove(path);
+                    }
                 }
             }
             free(path);
@@ -223,15 +225,17 @@ init_fuse(int *dev, dav_run_msgloop_fn *msg_loop, void **mdata,
             abort();
 
     *dev = open(path, O_RDWR | O_NONBLOCK);
-    if (*dev <= 0) {
-        system("/sbin/modprobe fuse &>/dev/null");
+    if (*dev <= 0 && system("/sbin/modprobe fuse &>/dev/null") == 0) {
         *dev = open(path, O_RDWR | O_NONBLOCK);
     }
     if (*dev <= 0) {
         if (mknod(path, S_IFCHR, makedev(FUSE_MAJOR, FUSE_MINOR)) == 0) {
-            chown(path, 0, 0);
-            chmod(path, S_IRUSR | S_IWUSR);
-            *dev = open(path, O_RDWR | O_NONBLOCK);
+             if (chown(path, 0, 0) == 0
+                    && chmod(path, S_IRUSR | S_IWUSR) == 0) {
+                *dev = open(path, O_RDWR | O_NONBLOCK);
+            } else {
+                remove(path);
+            }
         }
     }
 
@@ -248,12 +252,12 @@ init_fuse(int *dev, dav_run_msgloop_fn *msg_loop, void **mdata,
 #if SIZEOF_VOID_P == 8
     if (asprintf((char **) mdata, "fd=%i,rootmode=%o,user_id=%i,group_id=%i,"
                  "allow_other,max_read=%lu", *dev, mode, owner, group,
-                 *buf_size - 4096) < 0)
+                 (unsigned long int) (*buf_size - 4096)) < 0)
         abort();
 #else
     if (asprintf((char **) mdata, "fd=%i,rootmode=%o,user_id=%i,group_id=%i,"
                  "allow_other,max_read=%u", *dev, mode, owner, group,
-                 *buf_size - 4096) < 0)
+                 (unsigned int) (*buf_size - 4096)) < 0)
         abort();
 #endif
     if (mount(url, mpoint, "fuse", mopts, *mdata) == 0) {
