@@ -188,9 +188,6 @@ eval_modes(dav_args *args);
 static void
 get_options(dav_args *args, char *option);
 
-static int
-ignore_home(const char *name, const char *ignore_list);
-
 static dav_args *
 new_args(void);
 
@@ -535,7 +532,7 @@ check_dirs(dav_args *args)
                 char *template = ne_concat(DAV_DATA_DIR, "/", DAV_CONFIG, NULL);
                 char *command = ne_concat("cp ", template, " ", file_name,
                                           NULL);
-                system(command);
+                if (system(command) != 0);
                 free(command);
                 free(template);
             }
@@ -679,10 +676,17 @@ check_fstab(const dav_args *args)
 {
     dav_args *n_args = new_args();
     n_args->mopts = DAV_USER_MOPTS;
-
     setfsent();
     struct fstab *ft = getfsfile(mpoint);
-    if (!ft || !ft->fs_spec)
+ 
+    if (!ft) {
+        char *mp = NULL;
+        if (asprintf(&mp, "%s/", mpoint) < 0) abort();
+        ft = getfsfile(mp);
+        if (mp) free(mp);
+    }
+
+   if (!ft || !ft->fs_spec)
         error(EXIT_FAILURE, 0, _("no entry for %s found in %s"), url,
               _PATH_FSTAB);
 
@@ -777,31 +781,6 @@ check_mountpoint(dav_args *args)
     if (access(mpoint, F_OK) != 0)
         error(EXIT_FAILURE, 0, _("mount point %s does not exist"), mpoint);
 
-    if (getuid() != 0) {
-        pw = getpwuid(getuid());
-        if (!pw)
-            error(EXIT_FAILURE, errno, _("can't read user data base"));
-        if (!pw->pw_dir)
-            error(EXIT_FAILURE, 0, _("can't read user data base"));
-        if(strstr(mpoint, pw->pw_dir) != mpoint) {
-            setpwent();
-            pw = getpwent();
-            while (pw) {
-                if (!pw->pw_dir || !pw->pw_name)
-                    error(EXIT_FAILURE, 0, _("can't read user data base"));
-                if (pw->pw_uid != args->uid && strlen(pw->pw_dir) > 0
-                        && strstr(mpoint, pw->pw_dir) == mpoint
-                        && !ignore_home(pw->pw_name, args->ignore_home))
-                    error(EXIT_FAILURE, 0,
-                          _("%s is the home directory of user %s.\n"
-                          "You can't mount into another users home directory"),
-                          pw->pw_dir, pw->pw_name);
-                pw = getpwent();
-            }
-            endpwent();
-        }
-    }
-
     if (args->debug & DAV_DBG_CONFIG)
         syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG), "mountpoint: %s", mpoint);
 }
@@ -855,10 +834,23 @@ check_permissions(dav_args *args)
         error(EXIT_FAILURE, errno, _("group %s does not exist"),
               args->dav_group);
     if (pw->pw_gid != grp->gr_gid) {
-        char **members = grp->gr_mem;
-        while (*members && strcmp(*members, pw->pw_name) != 0)
-            members++;
-        if (!*members)
+        int ngroups = getgroups(0, NULL);
+        gid_t *groups = NULL;
+        if (ngroups > 0) {
+            groups = (gid_t *) malloc(ngroups * sizeof(gid_t));
+            if (!groups) abort();
+            if (getgroups(ngroups, groups) < 0)
+                error(EXIT_FAILURE, 0, _("can't read group data base"));
+        } else {
+            error(EXIT_FAILURE, 0, _("can't read group data base"));
+        }
+        int i;
+        for (i = 0; i < ngroups; i++) {
+            if (grp->gr_gid == groups[i])
+                break;
+        }
+        free(groups);
+        if (i == ngroups)
             error(EXIT_FAILURE, 0, _("user %s must be member of group %s"),
                   pw->pw_name, grp->gr_name);
     }
@@ -1418,8 +1410,6 @@ delete_args(dav_args *args)
         free(args->dav_user);
     if (args->dav_group)
         free(args->dav_group);
-    if (args->ignore_home)
-        free(args->ignore_home);
     if (args->conf)
         free(args->conf);
     if (args->add_mopts)
@@ -1693,26 +1683,6 @@ get_options(dav_args *args, char *option)
 }
 
 
-/* Checks whether name ist in ignore_list.
-   name        : name of a system user. Must not be NULL.
-   ignore_list : comma seperated list of system users. May be NULL.
-   return value : 1 if name is in ignore_list, 0 otherwise. */
-static int
-ignore_home(const char *name, const char *ignore_list)
-{
-    if (!ignore_list)
-        return 0;
-    char * s = strstr(ignore_list, name);
-    if (!s)
-        return 0;
-    if (s != ignore_list && *(s - 1) != ',')
-        return 0;
-    if (*(s + strlen(name)) != '\0' && *(s + strlen(name)) != ',')
-        return 0;
-    return 1;
-}
-
-
 /* Allocates a new dav_args-structure and initializes it.
    All members are set to reasonable defaults. */
 static dav_args *
@@ -1732,7 +1702,6 @@ new_args(void)
 
     args->dav_user = ne_strdup(DAV_USER);
     args->dav_group = ne_strdup(DAV_GROUP);
-    args->ignore_home = NULL;
 
     if (getuid() != 0) {
         args->conf = ne_concat(user_dir, "/", DAV_CONFIG, NULL);
@@ -1828,7 +1797,7 @@ log_dbg_cmdline(char *argv[])
     char *cmdline;
     if (argz_create(argv, &cmdline, &len) == 0) {
         argz_stringify(cmdline, len, ' ');
-        syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG), cmdline);
+        syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG), "%s", cmdline);
         free(cmdline);
     }
 }
@@ -1847,8 +1816,6 @@ log_dbg_config(char *argv[], dav_args *args)
            "  dav_user: %s", args->dav_user);
     syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG),
            "  dav_group: %s", args->dav_group);
-    syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG),
-           "  ignore_home: %s", args->ignore_home);
     syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG),
            "  conf: %s", args->conf);
     syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG),
@@ -1965,11 +1932,11 @@ log_dbg_config(char *argv[], dav_args *args)
    it must be escaped if there is more than on '\'-character in succession.
    Whitespace characters other than ' ' and tab must only occur at the end of
    the line.
-   line    : the line to be parsed
+   line    : the line to be parsed. It will be changed by this function.
    parmc   : the max. number of parameters. It is an error, if more than parmc
              parameters are found
-   parmv[] : the parameters found are returned in this array. They are newly
-             allocated strings and must be freed by the calling function.
+   parmv[] : the parameters found are returned in this array. It contains
+             pointers into the rearranged line parameter.
    reurn value : the numer of parameters or -1 if an error occurs. */
 static int
 parse_line(char *line, int parmc, char *parmv[])
@@ -1987,27 +1954,27 @@ parse_line(char *line, int parmc, char *parmv[])
 
     int state = SPACE;
     int parm_no = 0;
-    char buf[254];
-    char *pos = buf;
-    char *end = buf + 253;
+    char *pos = line;
     char *p = line;
+    parmv[0] = line;
 
-    while ((state != END) && (state != ERROR)) {
+    while (state != END) {
         switch (state) {
         case SPACE:
             if (*p == '\0' || *p == '#' || *p == '\f' || *p == '\n'
                     || *p == '\r' || *p == '\v') {
                 state = END;
             } else if (*p == '\"') {
-                state = (parm_no < parmc) ? PARM_QUO : ERROR;
+                state = PARM_QUO;
             } else if (*p == '\\') {
-                state = (parm_no < parmc) ? PARM_ESC : ERROR;
+                state = PARM_ESC;
             } else if (isspace(*p)) {
                 ;
             } else {
                 *pos++ = *p;
-                state = (parm_no < parmc) ? PARM : ERROR;
+                state = PARM;
             }
+            if (parm_no >= parmc) return -1;
             break;
         case SPACE_EXP:
             if (*p == ' ' || *p == '\t') {
@@ -2016,65 +1983,60 @@ parse_line(char *line, int parmc, char *parmv[])
                        || *p == '\r' || *p == '\v') {
                 state = END;
             } else {
-                state = ERROR;
+                return -1;
             }
             break;
         case PARM:
             if (*p == '\"') {
-                state = ERROR;
+                return -1;
             } else if (*p == '\\') {
                 state = PARM_ESC;
             } else if (*p == ' ' || *p == '\t') {
-                parmv[parm_no++] = ne_strndup(buf, pos - buf);
-                pos = buf;
+                *pos++ = '\0';
+                parmv[++parm_no] = pos;
                 state = SPACE;
             } else if (isspace(*p) || *p == '\0' || *p == '#') {
-                parmv[parm_no++] = ne_strndup(buf, pos - buf);
-                pos = buf;
+                *pos = '\0';
+                parm_no++;
                 state = END;
             } else {
                 *pos++ = *p;
-                state = (pos < end) ? PARM : ERROR;
             }
             break;
         case PARM_ESC:
             if (*p == '\"' || *p == '\\' || *p == '#' || *p == ' '
                     || *p == '\t') {
                 *pos++ = *p;
-                state = (pos < end) ? PARM : ERROR;
+                state = PARM;
             } else {
-                state = ERROR;
+                return -1;
             }
             break;
         case PARM_QUO:
             if (*p == '\\') {
                 state = PARM_QUO_ESC;
             } else if (*p == '\"') {
-                parmv[parm_no++] = ne_strndup(buf, pos - buf);
-                pos = buf;
+                *pos++ = '\0';
+                parmv[++parm_no] = pos;
                 state = SPACE_EXP;
             } else if (*p == '\0' || *p == '\f' || *p == '\n'
                        || *p == '\r' || *p == '\v') {
-                state = ERROR;
+                return -1;
             } else {
                 *pos++ = *p;
-                state = (pos < end) ? PARM_QUO : ERROR;
             }
             break;
         case PARM_QUO_ESC:
             if (*p == '\"' || *p == '\\') {
                 *pos++ = *p;
-                state = (pos < end) ? PARM_QUO : ERROR;
+                state = PARM_QUO;
             } else if (*p == '\0' || *p == '\f' || *p == '\n'
                        || *p == '\r' || *p == '\v') {
-                state = ERROR;
+                return -1;
             } else {
                 *pos++ = '\\';
-                state = (pos < end) ? PARM_QUO : ERROR;
-                if (state == PARM_QUO) {
-                    *pos++ = *p;
-                    state = (pos < end) ? PARM_QUO : ERROR;
-                }
+                *pos++ = *p;
+                state = PARM_QUO;
             }
             break;
         }
@@ -2082,17 +2044,9 @@ parse_line(char *line, int parmc, char *parmv[])
     }
 
     int i;
-    if (state == END) {
-        for (i = parm_no; i < parmc; i++)
-            parmv[i] = NULL;
-        return parm_no;
-    } else {
-        for (i = 0; i < parm_no; i++) {
-            free(parmv[i]);
-            parmv[i] = NULL;
-        }
-        return -1;
-    }
+    for (i = parm_no; i < parmc; i++)
+        parmv[i] = NULL;
+    return parm_no;
 }
 
 
@@ -2175,10 +2129,6 @@ read_config(dav_args *args, const char * filename, int system)
                 if (args->dav_group)
                     free(args->dav_group);
                 args->dav_group = ne_strdup(parmv[1]); 
-            } else if (system && strcmp(parmv[0], "ignore_home") == 0) {
-                if (args->ignore_home)
-                    free(args->ignore_home);
-                args->ignore_home = ne_strdup(parmv[1]); 
             } else if (strcmp(parmv[0], "kernel_fs") == 0) {
                 if (args->kernel_fs)
                     free(args->kernel_fs);
@@ -2293,8 +2243,6 @@ read_config(dav_args *args, const char * filename, int system)
                           _("malformed line"));
         }
 
-        for (parmc = 0; parmc < count; parmc++)
-            free(parmv[parmc]);
         length = getline(&line, &n, file);
         lineno++;
     }
@@ -2472,10 +2420,6 @@ read_secrets(dav_args *args, const char *filename)
             if (path) free(path);
         }
 
-        for (parmc = 0; parmc < count; parmc++) {
-            memset(parmv[parmc], '\0', strlen(parmv[parmc]));
-            free(parmv[parmc]);
-        }
         memset(line, '\0', strlen(line));
         length = getline(&line, &n, file);
         lineno++;
