@@ -150,7 +150,7 @@ static const ne_propname quota_names[] = {
 
 static size_t log_bufsize = 512;
 
-static char *none_match_header = "If-None-Match: *\n";
+static char *none_match_header = "If-None-Match: *\r\n";
 
 
 /* Private global variables */
@@ -410,11 +410,14 @@ dav_init_webdav(const dav_args *args)
         }
 
         if (args->clicert) {
-            uid_t orig = geteuid();
-            seteuid(0);
             ne_ssl_client_cert *client_cert
                     = ne_ssl_clicert_read(args->clicert);
-            seteuid(orig);
+            if (!client_cert) {
+                uid_t orig = geteuid();
+                seteuid(0);
+                client_cert = ne_ssl_clicert_read(args->clicert);
+                seteuid(orig);
+            }
             if (!client_cert)
                 error(EXIT_FAILURE, 0, _("can't read client certificate %s"),
                       args->clicert);
@@ -1150,7 +1153,7 @@ dav_quota(const char *path, off64_t *total, off64_t *used)
         if (!ret) {
             if (ctx.error)
                 ret = EIO;
-        } else if (ret == EINVAL) {
+        } else if (ret != EAGAIN) {
             use_userinfo = 0;
         }
     }
@@ -1341,6 +1344,7 @@ get_ne_error(const char *method)
         case 301:           /* Moved Permanently */
         case 303:           /* See Other */
         case 404:           /* Not Found */
+        case 405:           /* Method Not Allowed */
         case 410:           /* Gone */
             return ENOENT;
         case 408:           /* Request Timeout */
@@ -1350,7 +1354,6 @@ get_ne_error(const char *method)
             return EACCES;
         case 400:           /* Bad Request */
         case 403:           /* Forbidden */
-        case 405:           /* Method Not Allowed */
         case 409:           /* Conflict */
         case 411:           /* Length Required */
         case 412:           /* Precondition Failed */
@@ -1475,7 +1478,7 @@ log_writer(void *cookie, const char *buffer, size_t size)
             written++;
         }
         *cpos = '\0';
-        syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG), (char *) cookie);
+        syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG), "%s", (char *) cookie);
     }
     return written;
 }
