@@ -1,28 +1,25 @@
-/* 
-** Send requests to the WebDAV server.
- */
+/*  webdav.h: send requests to the WebDAV server.
+    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
 
-/*
- *  This file is part of davfs2.
- *
- *  davfs2 is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  davfs2 is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with davfs2; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+    This file is part of davfs2.
+
+    davfs2 is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    davfs2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with davfs2; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 
-#ifndef __WEBDAV_H__
-#define __WEBDAV_H__
+#ifndef DAV_WEBDAV_H
+#define DAV_WEBDAV_H
 
 
 /* Data Types */
@@ -57,17 +54,8 @@ struct dav_props {
    It must only be initialized once, as it depends on global variables.
    If an error occurs, the program is terminated.
    paramters: if not self explaining, please see mount_davfs.h, struct args. */
-void dav_init_webdav(const char *scheme, const char *host, int port,
-                     time_t connect_timeout, time_t read_timeout, int use_locks,
-                     time_t l_timeout, const char *servercert,
-                     const char *clicert, const char *clicert_pw, int askauth,
-                     const char *user, const char *passwd, int useproxy,
-                     const char *p_host, int p_port, const char *p_user,
-                     const char *p_passwd, const char *lock_owner,
-                     int displayname, int expect100, int if_match_bug,
-                     int d_w_etags, const char *s_charset, const char *header,
-                     int allow_cookie, int prechck, int ignore_dav_hdr,
-                     int debug);
+void
+dav_init_webdav(const dav_args* args);
 
 
 /* Does an OPTIONS request to check the server capabilities. In case of
@@ -76,12 +64,14 @@ void dav_init_webdav(const char *scheme, const char *host, int port,
    to NULL.
    path : Path to the root collection.
    return value : 0 on success or an apropriate error code. */
-int dav_init_connection(const char *path);
+int
+dav_init_connection(const char *path);
 
 
 /* Releases all locks (if possible) and closes the session.
    Does not free memory held by the session. */
-void dav_close_webdav(void);
+void
+dav_close_webdav(void);
 
 
 /* Converts the character encoding of s from and to the local encoding.
@@ -90,10 +80,14 @@ void dav_close_webdav(void);
    If no conversion is necessary, it just returns a copy of s.
    name : string to be converted.
    return value : the converted string, newly allocated. */
-char *dav_conv_from_utf_8(const char *s);
-char *dav_conv_to_utf_8(const char *s);
-char *dav_conv_from_server_enc(const char *s);
-char *dav_conv_to_server_enc(const char *s);
+char *
+dav_conv_from_utf_8(const char *s);
+char *
+dav_conv_to_utf_8(const char *s);
+char *
+dav_conv_from_server_enc(const char *s);
+char *
+dav_conv_to_server_enc(const char *s);
 
 
 /* Deletes file path on the server.
@@ -102,7 +96,8 @@ char *dav_conv_to_server_enc(const char *s);
    expire : If not 0, the resource is assumed to be locked and the lock
             will be removed after successful delete.
    return value : 0 on success; an appropriate file error code otherwise. */
-int dav_delete(const char *path, time_t *expire);
+int
+dav_delete(const char *path, time_t *expire);
 
 
 /* Deletes collection path on the server.
@@ -112,7 +107,8 @@ int dav_delete_dir(const char *path);
 
 
 /* Frees any resources held by props and finally frees props. */
-void dav_delete_props(dav_props *props);
+void
+dav_delete_props(dav_props *props);
 
 
 /* Retrieves properties for the directory named by path and its
@@ -125,7 +121,8 @@ void dav_delete_props(dav_props *props);
    *props : Will point to the list of properties on return. NULL in case of
             an error.
    return value : 0 on success; an appropriate file error code otherwise. */
-int dav_get_collection(const char *path, dav_props **props);
+int
+dav_get_collection(const char *path, dav_props **props);
 
 
 /* Fetches file path from the server, stores it in cache_path and updates
@@ -151,15 +148,17 @@ int dav_get_collection(const char *path, dav_props **props);
                 has been replaced by a new version. May be NULL.
    return value : 0 on success; an appropriate file error code otherwise.
                   Not-Modified counts as success. */
-int dav_get_file(const char *path, const char *cache_path, off_t *size,
-                 char **etag, time_t *mtime, char **mime, int *modified);
+int
+dav_get_file(const char *path, const char *cache_path, off_t *size,
+             char **etag, time_t *mtime, char **mime, int *modified);
 
 
 /* Returns the error string from the last WebDAV request.
    Note: This will not be usefull in any case, because the last function
          called may have done more then one request (e.g. an additional
          lock discover. But it is usefull for dav_get_collection(). */
-const char *dav_get_webdav_error(void);
+const char *
+dav_get_webdav_error(void);
 
 
 /* Tests for the existence of file path and uptdates etag, mtime and length.
@@ -172,8 +171,9 @@ const char *dav_get_webdav_error(void);
    mime  : Points to mime_type; will be updated on success. May be NULL.
    return value : 0 if the file exists; an appropriate file error code
                   otherwise. */
-int dav_head(const char *path, char **etag, time_t *mtime, off_t *length,
-             char **mime);
+int
+dav_head(const char *path, char **etag, time_t *mtime, off_t *length,
+         char **mime);
 
 
 /* Locks the file path on the server with an excluse write lock and updates
@@ -195,7 +195,8 @@ int dav_head(const char *path, char **etag, time_t *mtime, off_t *length,
              responds with "201 CREATED", it will be set to 1.
    return value : 0 on success; an appropriate file error code
                   otherwise. */
-int dav_lock(const char *path, time_t *expire, int *exists);
+int
+dav_lock(const char *path, time_t *expire, int *exists);
 
 
 /* Refreshes the lock for file path and updates expire.
@@ -209,14 +210,16 @@ void dav_lock_refresh(const char *path, time_t *expire);
 /* Creates a new collection on the server.
    path : Absolute path of the new collection on the server.
    return value : 0 on success; an appropriate file error code otherwise. */
-int dav_make_collection(const char *path);
+int
+dav_make_collection(const char *path);
 
 
 /* Moves resource src to the new name/location dst.
    src : Absolute path of the resource on the server.
    dst : New absolute path of the resource on the server.
    return value : 0 on success; an appropriate file error code otherwise. */
-int dav_move(const char *src, const char *dst);
+int
+dav_move(const char *src, const char *dst);
 
 
 /* Stores the contents of file cache_path on the server location path and
@@ -239,33 +242,39 @@ int dav_move(const char *src, const char *dst);
                 If a mime_type is set, the Content-Type header will be sent.
    execute    : if 1 set execute property, else no change of execute property.
    return value : 0 on success; an appropriate file error code otherwise. */
-int dav_put(const char *path, const char *cache_path, int *exists,
-            time_t *expire, char **etag, time_t *mtime, char **mime,
-            int execute);
+int
+dav_put(const char *path, const char *cache_path, int *exists, time_t *expire,
+        char **etag, time_t *mtime, char **mime, int execute);
 
 /* Makes a PROPFIND request for path to get quota information (RFC 4331)
-   and places them in available and used. If quota information is not
+   and places them in total and used.
+   toatal is the sum of quota-available-bytes and quota-used-bytes.
+   If quota information is not
    available, an error is returned and available and used are not changed. */ 
-int dav_quota(const char *path, off_t *available, off_t *used);
+int
+dav_quota(const char *path, off_t *total, off_t *used);
 
 
 /* Sets or resets the execute property of file path.
    path : Absolute path of the file on the server.
    set  : boolean value; 0 reset execute property; 1 set execute property. */
-int dav_set_execute(const char *path, int set);
+int
+dav_set_execute(const char *path, int set);
 
 
 /* Tells webdav that no more terminal is available, so errors can only
  * be logged. Before this function is invoced webdav tries to 
  * communicate with the user when problems occur. */
-void dav_set_no_terminal(void);
+void
+dav_set_no_terminal(void);
 
 
 /* Releases the lock on file path on the serverand sets expire to 0.
    path : Absolute path of the file on the server.
    return value : 0 if no error occured; an appropriate file error code
                   otherwise. */
-int dav_unlock(const char *path, time_t *expire);
+int
+dav_unlock(const char *path, time_t *expire);
 
 
-#endif
+#endif /* DAV_WEBDAV_H */
